OC.L10N.register(
    "settings",
    {
    "Security & setup warnings" : "Security & setup warnings",
    "Sharing" : "Sharing",
    "Server-side encryption" : "Server-side encryption",
    "External Storage" : "External Storage",
    "Cron" : "Cron",
    "Email server" : "Email server",
    "Log" : "Log",
    "Server Status" : "Server Status",
    "Tips & tricks" : "Tips & tricks",
    "Updates" : "Updates",
    "Authentication error" : "Authentication error",
    "Your full name has been changed." : "Your full name has been changed.",
    "Unable to change full name" : "Unable to change full name",
    "Couldn't remove app." : "Couldn't remove app.",
    "Language changed" : "Language changed",
    "Invalid request" : "Invalid request",
    "Admins can't remove themself from the admin group" : "Admins can't remove themselves from the admin group",
    "Unable to add user to group %s" : "Unable to add user to group %s",
    "Unable to remove user from group %s" : "Unable to remove user from group %s",
    "Couldn't update app." : "Couldn't update app.",
    "Wrong password" : "Incorrect password",
    "No user supplied" : "No user supplied",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Please provide an admin recovery password, otherwise all user data will be lost",
    "Wrong admin recovery password. Please check the password and try again." : "Incorrect admin recovery password. Please check the password and try again.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Backend doesn't support password change, but the user's encryption key was successfully updated.",
    "Unable to change password" : "Unable to change password",
    "Enabled" : "Enabled",
    "Not enabled" : "Not enabled",
    "A problem occurred, please check your log files (Error: %s)" : "A problem occurred, please check your log files (Error: %s)",
    "Migration Completed" : "Migration Completed",
    "Group already exists." : "Group already exists.",
    "Unable to add group." : "Unable to add group.",
    "Unable to delete group." : "Unable to delete group.",
    "log-level out of allowed range" : "log-level out of allowed range",
    "Saved" : "Saved",
    "test email settings" : "test email settings",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "A problem occurred while sending the email. Please revise your settings. (Error: %s)",
    "Email sent" : "Email sent",
    "You need to set your user email before being able to send test emails." : "You need to set your user email before being able to send test emails.",
    "Invalid mail address" : "Invalid mail address",
    "A user with that name already exists." : "A user with that name already exists.",
    "Unable to create user." : "Unable to create user.",
    "Your %s account was created" : "Your %s account was created",
    "Unable to delete user." : "Unable to delete user.",
    "Forbidden" : "Forbidden",
    "Invalid user" : "Invalid user",
    "Unable to change mail address" : "Unable to change mail address",
    "Email saved" : "Email saved",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Are you really sure you want add \"{domain}\" as a trusted domain?",
    "Add trusted domain" : "Add trusted domain",
    "Migration in progress. Please wait until the migration is finished" : "Migration in progress. Please wait until the migration is finished",
    "Migration started …" : "Migration started …",
    "Sending..." : "Sending...",
    "Official" : "Official",
    "Approved" : "Approved",
    "Experimental" : "Experimental",
    "All" : "All",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use.",
    "Update to %s" : "Update to %s",
    "Please wait...." : "Please wait....",
    "Error while disabling app" : "Error whilst disabling app",
    "Disable" : "Disable",
    "Enable" : "Enable",
    "Error while enabling app" : "Error whilst enabling app",
    "Updating...." : "Updating....",
    "Error while updating app" : "Error whilst updating app",
    "Updated" : "Updated",
    "Uninstalling ...." : "Uninstalling...",
    "Error while uninstalling app" : "Error whilst uninstalling app",
    "Uninstall" : "Uninstall",
    "Select a profile picture" : "Select a profile picture",
    "Very weak password" : "Very weak password",
    "Weak password" : "Weak password",
    "So-so password" : "So-so password",
    "Good password" : "Good password",
    "Strong password" : "Strong password",
    "Valid until {date}" : "Valid until {date}",
    "Delete" : "Delete",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "An error occurred. Please upload an ASCII-encoded PEM certificate.",
    "Groups" : "Groups",
    "Unable to delete {objName}" : "Unable to delete {objName}",
    "Error creating group" : "Error creating group",
    "A valid group name must be provided" : "A valid group name must be provided",
    "deleted {groupName}" : "deleted {groupName}",
    "undo" : "undo",
    "no group" : "no group",
    "never" : "never",
    "deleted {userName}" : "deleted {userName}",
    "add group" : "add group",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Changing the password will result in data loss, because data recovery is not available for this user",
    "A valid username must be provided" : "A valid username must be provided",
    "Error creating user" : "Error creating user",
    "A valid password must be provided" : "A valid password must be provided",
    "A valid email must be provided" : "A valid email must be provided",
    "__language_name__" : "English (British English)",
    "Sync clients" : "Sync clients",
    "Personal info" : "Personal info",
    "SSL root certificates" : "SSL root certificates",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Everything (fatal issues, errors, warnings, info, debug)",
    "Info, warnings, errors and fatal issues" : "Info, warnings, errors and fatal issues",
    "Warnings, errors and fatal issues" : "Warnings, errors and fatal issues",
    "Errors and fatal issues" : "Errors and fatal issues",
    "Fatal issues only" : "Fatal issues only",
    "None" : "None",
    "Login" : "Login",
    "Plain" : "Plain",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response.",
    "Please check the installation documentation for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Please check the installation documentation for php configuration notes and the php configuration of your server, especially when using php-fpm.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator.",
    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "The PHP module 'fileinfo' is missing. We strongly recommend enabling this module to get best results with mime-type detection.",
    "System locale can not be set to a one which supports UTF-8." : "System locale can not be set to a one which supports UTF-8.",
    "This means that there might be problems with certain characters in file names." : "This means that there might be problems with certain characters in file names.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "We strongly suggest installing the required packages on your system to support one of the following locales: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:",
    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>.",
    "Open documentation" : "Open documentation",
    "Allow apps to use the Share API" : "Allow apps to use the Share API",
    "Allow users to share via link" : "Allow users to share via link",
    "Enforce password protection" : "Enforce password protection",
    "Allow public uploads" : "Allow public uploads",
    "Allow users to send mail notification for shared files" : "Allow users to send mail notification for shared files",
    "Set default expiration date" : "Set default expiry date",
    "Expire after " : "Expire after ",
    "days" : "days",
    "Enforce expiration date" : "Enforce expiry date",
    "Allow resharing" : "Allow resharing",
    "Restrict users to only share with users in their groups" : "Restrict users to only share with users in their groups",
    "Allow users to send mail notification for shared files to other users" : "Allow users to send email notification for shared files to other users",
    "Exclude groups from sharing" : "Exclude groups from sharing",
    "These groups will still be able to receive shares, but not to initiate them." : "These groups will still be able to receive shares, but not to initiate them.",
    "Last cron job execution: %s." : "Last cron job execution: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Last cron job execution: %s. Something seems wrong.",
    "Cron was not executed yet!" : "Cron was not executed yet!",
    "Execute one task with each page loaded" : "Execute one task with each page loaded",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php is registered at a webcron service to call cron.php every 15 minutes over http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Use system's cron service to call the cron.php file every 15 minutes.",
    "Enable server-side encryption" : "Enable server-side encryption",
    "Encryption is a one way process. Once encryption is enabled, all files from that point forward will be encrypted on the server and it will not be possible to disable encryption at a later date. This is the final warning: Do you really want to enable encryption?" : "Encryption is a one way process. Once encryption is enabled, all files from that point forward will be encrypted on the server and it will not be possible to disable encryption at a later date. This is the final warning: Do you really want to enable encryption?",
    "Enable encryption" : "Enable encryption",
    "No encryption module loaded, please enable an encryption module in the app menu." : "No encryption module loaded, please enable an encryption module in the app menu.",
    "Select default encryption module:" : "Select default encryption module:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one.",
    "Start migration" : "Start migration",
    "This is used for sending out notifications." : "This is used for sending out notifications.",
    "Send mode" : "Send mode",
    "Encryption" : "Encryption",
    "From address" : "From address",
    "mail" : "mail",
    "Authentication method" : "Authentication method",
    "Authentication required" : "Authentication required",
    "Server address" : "Server address",
    "Port" : "Port",
    "Credentials" : "Credentials",
    "SMTP Username" : "SMTP Username",
    "SMTP Password" : "SMTP Password",
    "Store credentials" : "Store credentials",
    "Test email settings" : "Test email settings",
    "Send email" : "Send email",
    "Log level" : "Log level",
    "Download logfile" : "Download logfile",
    "More" : "More",
    "Less" : "Less",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "The logfile is larger than 100 MB. Downloading it may take some time!",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite is used as database. For larger installations, we recommend you switch to a different database backend.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Especially when using the desktop client for file syncing, the use of SQLite is discouraged.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>.",
    "How to do backups" : "How to do backups",
    "Advanced monitoring" : "Advanced monitoring",
    "Performance tuning" : "Performance tuning",
    "Improving the config.php" : "Improving the config.php",
    "Theming" : "Theming",
    "Hardening and security guidance" : "Hardening and security guidance",
    "Version" : "Version",
    "Developer documentation" : "Developer documentation",
    "Experimental applications ahead" : "Experimental applications ahead",
    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches.",
    "by" : "by",
    "licensed" : "licensed",
    "Documentation:" : "Documentation:",
    "User Documentation" : "User Documentation",
    "Admin Documentation" : "Admin Documentation",
    "Show description …" : "Show description …",
    "Hide description …" : "Hide description …",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "This app cannot be installed because the following dependencies are not fulfilled:",
    "Enable only for specific groups" : "Enable only for specific groups",
    "Uninstall App" : "Uninstall App",
    "Enable experimental apps" : "Enable experimental apps",
    "No apps found for your version" : "No apps found for your version",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Cheers!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n",
    "User documentation" : "User documentation",
    "Administrator documentation" : "Administrator documentation",
    "Online documentation" : "Online documentation",
    "Forum" : "Forum",
    "Issue tracker" : "Issue tracker",
    "Commercial support" : "Commercial support",
    "Get the apps to sync your files" : "Get the apps to sync your files",
    "Desktop client" : "Desktop client",
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!",
    "Show First Run Wizard again" : "Show First Run Wizard again",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "You have used <strong>%s</strong> of the available <strong>%s</strong>",
    "Password" : "Password",
    "Unable to change your password" : "Unable to change your password",
    "Current password" : "Current password",
    "New password" : "New password",
    "Change password" : "Change password",
    "Full name" : "Full name",
    "No display name set" : "No display name set",
    "Email" : "Email",
    "Your email address" : "Your email address",
    "Fill in an email address to enable password recovery and receive notifications" : "Fill in an email address to enable password recovery and receive notifications",
    "No email address set" : "No email address set",
    "You are member of the following groups:" : "You are member of the following groups:",
    "Profile picture" : "Profile picture",
    "Upload new" : "Upload new",
    "Select new from Files" : "Select new from Files",
    "Remove image" : "Remove image",
    "Either png or jpg. Ideally square but you will be able to crop it." : "Either png or jpg. Ideally square but you will be able to crop it.",
    "Your avatar is provided by your original account." : "Your avatar is provided by your original account.",
    "Cancel" : "Cancel",
    "Choose as profile image" : "Choose as profile image",
    "Language" : "Language",
    "Help translate" : "Help translate",
    "Common Name" : "Common Name",
    "Valid until" : "Valid until",
    "Issued By" : "Issued By",
    "Valid until %s" : "Valid until %s",
    "Import root certificate" : "Import root certificate",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public Licence\">AGPL</abbr>{linkclose}.",
    "Show storage location" : "Show storage location",
    "Show last log in" : "Show last log in",
    "Show user backend" : "Show user backend",
    "Send email to new user" : "Send email to new user",
    "Show email address" : "Show email address",
    "Username" : "Username",
    "E-Mail" : "E-Mail",
    "Create" : "Create",
    "Admin Recovery Password" : "Admin Recovery Password",
    "Enter the recovery password in order to recover the users files during password change" : "Enter the recovery password in order to recover the user's files during password change",
    "Search Users" : "Search Users",
    "Add Group" : "Add Group",
    "Group" : "Group",
    "Everyone" : "Everyone",
    "Admins" : "Admins",
    "Default Quota" : "Default Quota",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Please enter storage quota (e.g. \"512 MB\" or \"12 GB\")",
    "Unlimited" : "Unlimited",
    "Other" : "Other",
    "Full Name" : "Full Name",
    "Group Admin for" : "Group Admin for",
    "Quota" : "Quota",
    "Storage Location" : "Storage Location",
    "User Backend" : "User Backend",
    "Last Login" : "Last Login",
    "change full name" : "change full name",
    "set new password" : "set new password",
    "change email address" : "change email address",
    "Default" : "Default"
},
"nplurals=2; plural=(n != 1);");
